import { jsx as _jsx } from "react/jsx-runtime";
/**
 *
 * documentations:
 * https://www.npmjs.com/package/html-react-parser
 * https://github.com/wooorm/lowlight?tab=readme-ov-file
 * https://github.com/GeoffSelby/tailwind-highlightjs
 * https://highlightjs.org/examples (list of all available themes)
 * https://medium.com/@hizacharylee/simplify-syntax-highlighting-with-highlight-js-b65af3bdc509 (custom css theme, not used here)
 *
 */
import './index.css';
import parse, { attributesToProps, domToReact } from 'html-react-parser';
import { common, createLowlight } from 'lowlight';
import { toHtml } from 'hast-util-to-html';
const lowlight = createLowlight(common);
const parseHtml = (
/**
 * The stringified html to be parsed (to HTML).
 * example: `<p><h1>Hello there</h1><code>console.log('Hello, World!')</code></p>`
 */
text, classNames, language = 'javascript', options) => {
    const { codeClassName } = classNames || {};
    /**
     * Parse the html string content and highlight the code snippets
     */
    const defaultOptions = {
        /**
         * Replace the `<code>` with the highlighted code snippet
         * the string content of the `<code>` tag is transformed to stringified html using the lowlight library
         * the stringified html is then highlighted using the `highlight` theme
         * for that to work with tailwindcss, we are use tailwindcss plugin `tailwind-highlightjs`
         * hast trees as returned by lowlight can be serialized to HTML using `hast-util-to-html`
         * finally the highlighted code snippet is parsed to react component using the `parse` function of `html-react-parser`
         * @param domProps
         * @returns
         */
        replace(domProps) {
            const { name, children, attribs } = domProps;
            const Component = name;
            if (name) {
                const props = attributesToProps(attribs);
                // do not replace the `<pre>` tag
                if (name === 'pre')
                    return;
                /**
                 * Replace the `<code>` tag with the highlighted code snippet
                 * with the `hljs` class name to apply the highlight theme (see: https://highlightjs.org/examples/)
                 */
                if (name === 'code') {
                    const codeStr = domToReact(children);
                    const tree = lowlight.highlight(language, codeStr);
                    return (_jsx("code", { className: `hljs code-container ${codeClassName || ''}`, ...props, children: parse(toHtml(tree)) }));
                }
                if (name === 'image') {
                    return _jsx(Component, { ...props, className: (classNames === null || classNames === void 0 ? void 0 : classNames.imageClassName) || '' });
                }
                if (['br', 'hr', 'img'].find((currentName) => currentName === name)) {
                    return _jsx(Component, { ...props });
                }
                return (_jsx(Component, { className: (classNames === null || classNames === void 0 ? void 0 : classNames[`${name}ClassName`]) || '', ...props, children: domToReact(children) }));
            }
        }
    };
    /*
    * If the `<code>` tag is not found in the html string content
    * it means that there are no code snippets to be highlighted.
    */
    return parse(text, { ...defaultOptions, ...options });
};
const TiptapParser = ({ classNames, containerClassName, language, children, ...rest }) => {
    return (_jsx("div", { className: containerClassName, children: parseHtml(children, classNames, language, rest) }));
};
export default TiptapParser;
